# sundew ☀️
A new kind of testing framework for Python.

> **Warning**
> This projct is barely even a proof-of-concept still and is not close to being ready for production use. This warning will be updated/removed when that has changed!

## To-do
Major things that still need to be done before making public (in rough order):
[x] - Handle test failures
[ ] - Handle test errors
[ ] - Fixtures
[ ] - Write tests for sundew 🤭
[ ] - Figure out test naming
[ ] - Basic test selection support
[ ] - Asyncio support/examples
[ ] - Documentation
[ ] - Implement smart test runner
[ ] - Implement automatic sub-function test cases
[ ] - Implement untested sub-function detection
[ ] - Parallel test runner support
[ ] - Add code of conduct
[ ] - Add contribution guidelines
[ ] - Setup Github Actions to release new versions to PyPi
[ ] - Release first version to Pypi